@@ -22,12 +22,12 @@ import (
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
-	"github.com/knative/pkg/apis"
-	"github.com/knative/pkg/ptr"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 	"k8s.io/apimachinery/pkg/util/intstr"
 	"k8s.io/apimachinery/pkg/util/sets"
+	"knative.dev/pkg/apis"
+	"knative.dev/pkg/ptr"
 )
 
 func TestPodSpecValidation(t *testing.T) {
@@ -170,6 +170,15 @@ func TestPodSpecValidation(t *testing.T) {
 			}},
 		},
 		want: apis.ErrDisallowedFields("initContainers"),
+	}, {
+		name: "bad service account name",
+		ps: corev1.PodSpec{
+			Containers: []corev1.Container{{
+				Image: "busybox",
+			}},
+			ServiceAccountName: "foo@bar.baz",
+		},
+		want: apis.ErrInvalidValue("serviceAccountName", "foo@bar.baz"),
 	}}
 
 	for _, test := range tests {
@@ -240,13 +249,21 @@ func TestContainerValidation(t *testing.T) {
 			Ports: []corev1.ContainerPort{},
 		},
 		want: nil,
+	}, {
+		name: "has valid unnamed user port",
+		c: corev1.Container{
+			Image: "foo",
+			Ports: []corev1.ContainerPort{{
+				ContainerPort: 8181,
+			}},
+		},
+		want: nil,
 	}, {
 		name: "has valid user port http1",
 		c: corev1.Container{
 			Image: "foo",
 			Ports: []corev1.ContainerPort{{
-				Name:          "http1",
-				ContainerPort: 8081,
+				Name: "http1",
 			}},
 		},
 		want: nil,
@@ -255,8 +272,7 @@ func TestContainerValidation(t *testing.T) {
 		c: corev1.Container{
 			Image: "foo",
 			Ports: []corev1.ContainerPort{{
-				Name:          "h2c",
-				ContainerPort: 8081,
+				Name: "h2c",
 			}},
 		},
 		want: nil,
@@ -265,11 +281,9 @@ func TestContainerValidation(t *testing.T) {
 		c: corev1.Container{
 			Image: "foo",
 			Ports: []corev1.ContainerPort{{
-				Name:          "h2c",
-				ContainerPort: 8080,
+				Name: "h2c",
 			}, {
-				Name:          "http1",
-				ContainerPort: 8181,
+				Name: "http1",
 			}},
 		},
 		want: &apis.FieldError{
@@ -285,14 +299,14 @@ func TestContainerValidation(t *testing.T) {
 				ContainerPort: 65536,
 			}},
 		},
-		want: apis.ErrOutOfBoundsValue(65536, 1, 65535, "ports.containerPort"),
+		want: apis.ErrOutOfBoundsValue(65536, 0, 65535, "ports.containerPort"),
 	}, {
 		name: "has an empty port set",
 		c: corev1.Container{
 			Image: "foo",
 			Ports: []corev1.ContainerPort{{}},
 		},
-		want: apis.ErrOutOfBoundsValue(0, 1, 65535, "ports.containerPort"),
+		want: nil,
 	}, {
 		name: "has more than one unnamed port",
 		c: corev1.Container{
@@ -313,8 +327,7 @@ func TestContainerValidation(t *testing.T) {
 		c: corev1.Container{
 			Image: "foo",
 			Ports: []corev1.ContainerPort{{
-				Protocol:      corev1.ProtocolTCP,
-				ContainerPort: 8080,
+				Protocol: corev1.ProtocolTCP,
 			}},
 		},
 		want: nil,
@@ -323,8 +336,7 @@ func TestContainerValidation(t *testing.T) {
 		c: corev1.Container{
 			Image: "foo",
 			Ports: []corev1.ContainerPort{{
-				Protocol:      "tdp",
-				ContainerPort: 8080,
+				Protocol: "tdp",
 			}},
 		},
 		want: apis.ErrInvalidValue("tdp", "ports.protocol"),
@@ -333,8 +345,7 @@ func TestContainerValidation(t *testing.T) {
 		c: corev1.Container{
 			Image: "foo",
 			Ports: []corev1.ContainerPort{{
-				HostPort:      80,
-				ContainerPort: 8080,
+				HostPort: 80,
 			}},
 		},
 		want: apis.ErrDisallowedFields("ports.hostPort"),
@@ -343,8 +354,7 @@ func TestContainerValidation(t *testing.T) {
 		c: corev1.Container{
 			Image: "foo",
 			Ports: []corev1.ContainerPort{{
-				HostIP:        "127.0.0.1",
-				ContainerPort: 8080,
+				HostIP: "127.0.0.1",
 			}},
 		},
 		want: apis.ErrDisallowedFields("ports.hostIP"),
@@ -389,8 +399,7 @@ func TestContainerValidation(t *testing.T) {
 		c: corev1.Container{
 			Image: "foo",
 			Ports: []corev1.ContainerPort{{
-				Name:          "foobar",
-				ContainerPort: 8080,
+				Name: "foobar",
 			}},
 		},
 		want: &apis.FieldError{
@@ -490,6 +499,10 @@ func TestContainerValidation(t *testing.T) {
 		c: corev1.Container{
 			Image: "foo",
 			ReadinessProbe: &corev1.Probe{
+				PeriodSeconds:    1,
+				TimeoutSeconds:   1,
+				SuccessThreshold: 1,
+				FailureThreshold: 3,
 				Handler: corev1.Handler{
 					HTTPGet: &corev1.HTTPGetAction{
 						Path: "/",
@@ -503,11 +516,76 @@ func TestContainerValidation(t *testing.T) {
 			},
 		},
 		want: nil,
+	}, {
+		name: "valid with exec probes ",
+		c: corev1.Container{
+			Image: "foo",
+			ReadinessProbe: &corev1.Probe{
+				PeriodSeconds:    1,
+				TimeoutSeconds:   1,
+				SuccessThreshold: 1,
+				FailureThreshold: 3,
+				Handler: corev1.Handler{
+					HTTPGet: &corev1.HTTPGetAction{
+						Path: "/",
+					},
+				},
+			},
+			LivenessProbe: &corev1.Probe{
+				Handler: corev1.Handler{
+					Exec: &corev1.ExecAction{},
+				},
+			},
+		},
+		want: nil,
+	}, {
+		name: "invalid with no handler",
+		c: corev1.Container{
+			Image: "foo",
+			ReadinessProbe: &corev1.Probe{
+				PeriodSeconds:    1,
+				TimeoutSeconds:   1,
+				SuccessThreshold: 1,
+				FailureThreshold: 3,
+				Handler: corev1.Handler{
+					HTTPGet: &corev1.HTTPGetAction{
+						Path: "/",
+					},
+				},
+			},
+			LivenessProbe: &corev1.Probe{
+				Handler: corev1.Handler{},
+			},
+		},
+		want: apis.ErrMissingField("livenessProbe.handler"),
+	}, {
+		name: "invalid with multiple handlers",
+		c: corev1.Container{
+			Image: "foo",
+			ReadinessProbe: &corev1.Probe{
+				PeriodSeconds:    1,
+				TimeoutSeconds:   1,
+				SuccessThreshold: 1,
+				FailureThreshold: 3,
+				Handler: corev1.Handler{
+					HTTPGet: &corev1.HTTPGetAction{
+						Path: "/",
+					},
+					Exec:      &corev1.ExecAction{},
+					TCPSocket: &corev1.TCPSocketAction{},
+				},
+			},
+		},
+		want: apis.ErrMultipleOneOf("readinessProbe.exec", "readinessProbe.tcpSocket", "readinessProbe.httpGet"),
 	}, {
 		name: "invalid readiness http probe (has port)",
 		c: corev1.Container{
 			Image: "foo",
 			ReadinessProbe: &corev1.Probe{
+				PeriodSeconds:    1,
+				TimeoutSeconds:   1,
+				SuccessThreshold: 1,
+				FailureThreshold: 3,
 				Handler: corev1.Handler{
 					HTTPGet: &corev1.HTTPGetAction{
 						Path: "/",
@@ -517,6 +595,56 @@ func TestContainerValidation(t *testing.T) {
 			},
 		},
 		want: apis.ErrDisallowedFields("readinessProbe.httpGet.port"),
+	}, {
+		name: "invalid readiness probe (has failureThreshold while using special probe)",
+		c: corev1.Container{
+			Image: "foo",
+			ReadinessProbe: &corev1.Probe{
+				PeriodSeconds:    0,
+				FailureThreshold: 2,
+				SuccessThreshold: 1,
+				Handler: corev1.Handler{
+					HTTPGet: &corev1.HTTPGetAction{
+						Path: "/",
+					},
+				},
+			},
+		},
+		want: apis.ErrDisallowedFields("readinessProbe.failureThreshold"),
+	}, {
+		name: "invalid readiness probe (has timeoutSeconds while using special probe)",
+		c: corev1.Container{
+			Image: "foo",
+			ReadinessProbe: &corev1.Probe{
+				PeriodSeconds:    0,
+				TimeoutSeconds:   2,
+				SuccessThreshold: 1,
+				Handler: corev1.Handler{
+					HTTPGet: &corev1.HTTPGetAction{
+						Path: "/",
+					},
+				},
+			},
+		},
+		want: apis.ErrDisallowedFields("readinessProbe.timeoutSeconds"),
+	}, {
+		name: "out of bounds probe values",
+		c: corev1.Container{
+			Image: "foo",
+			ReadinessProbe: &corev1.Probe{
+				PeriodSeconds:    -1,
+				TimeoutSeconds:   0,
+				SuccessThreshold: 0,
+				FailureThreshold: 0,
+				Handler: corev1.Handler{
+					HTTPGet: &corev1.HTTPGetAction{},
+				},
+			},
+		},
+		want: apis.ErrOutOfBoundsValue(-1, 0, math.MaxInt32, "readinessProbe.periodSeconds").Also(
+			apis.ErrOutOfBoundsValue(0, 1, math.MaxInt32, "readinessProbe.timeoutSeconds")).Also(
+			apis.ErrOutOfBoundsValue(0, 1, math.MaxInt32, "readinessProbe.successThreshold")).Also(
+			apis.ErrOutOfBoundsValue(0, 1, math.MaxInt32, "readinessProbe.failureThreshold")),
 	}, {
 		name: "disallowed security context field",
 		c: corev1.Container{
