@@ -33,6 +33,15 @@ func TestGetDomainName(t *testing.T) {
 nameserver 1.1.1.1
 search default.svc.abc.com svc.abc.com abc.com
 options ndots:5
+`,
+			want: "abc.com",
+		},
+		{
+			name: "all good with trailing dot",
+			resolvConf: `
+nameserver 1.1.1.1
+search default.svc.abc.com. svc.abc.com. abc.com.
+options ndots:5
 `,
 			want: "abc.com",
 		},
